@@ -7,11 +7,12 @@ OC.L10N.register(
     "Copy link" : "ສຳເນົາລິງ",
     "Edit" : "ແກ້ໄຂ",
     "Delete" : "ລຶບ",
+    "Create new" : "ສ້າງໃຫມ່",
     "Shared with you by" : "ແບ່ງປັນໂດຍທ່ານ",
+    "Empty trash bin" : "ລ້າງຖັງຂີ້ເຫຍື່ອ",
     "Name" : "ຊື່",
     "Deleted" : "ລືບ",
     "Restore" : "ການກຸ້ຄຶນ",
-    "Empty trash bin" : "ລ້າງຖັງຂີ້ເຫຍື່ອ",
     "Share link" : "ແບ່ງປັນລິງ",
     "Delete share link" : "ລົບລິງແບ່ງປັນ",
     "Save" : "ບັນທຶກ",
@@ -26,15 +27,11 @@ OC.L10N.register(
     "Available" : "ມີຢູ່",
     "Not available" : "ບໍ່ມີ",
     "Unknown" : "ບໍ່ຮູ້",
-    "Send email" : "ສົ່ງອີເມວ",
     "never" : "ບໍ່ເຄີຍ",
-    "More" : "ເພີ່ມເຕີມ",
     "Personal" : "ສ່ວນບຸກຄົນ",
-    "Details" : "ລາຍລະອຽດ",
     "Close" : "ປິດ",
     "Daily" : "ລາຍວັນ",
     "Weekly" : "ອາທິດ",
-    "Review" : "ເບິ່ງຄຶນ",
-    "Mail" : "ຈົດໝາຍ"
+    "Details" : "ລາຍລະອຽດ"
 },
 "nplurals=1; plural=0;");
