@@ -7,6 +7,7 @@ OC.L10N.register(
     "Copy link" : "Kopiraj vezu",
     "Edit" : "Izmeni",
     "Delete" : "Delete",
+    "Empty trash bin" : "Isprazni kantu",
     "Name" : "Ime",
     "Deleted" : "Obrisano",
     "Delete permanently" : "Obriši zauvek",
@@ -17,6 +18,7 @@ OC.L10N.register(
     "Filename" : "Ime fajla",
     "Cancel" : "Cancel",
     "List view" : "Prikaz liste",
+    "Update" : "Ažuriraj",
     "Description" : "Opis",
     "Add" : "Dodaj",
     "Monday" : "Ponedeljak",
@@ -26,17 +28,17 @@ OC.L10N.register(
     "Friday" : "Petak",
     "Saturday" : "Subota",
     "Sunday" : "Nedelja",
-    "Update" : "Ažuriraj",
     "Email" : "email",
+    "Proceed" : "Nastavi",
+    "Out of office" : "Van kancelarije",
+    "Done" : "Gotovo",
     "Unknown" : "Nepoznato",
     "never" : "never",
-    "More" : "More",
-    "Details" : "Detalji",
     "Close" : "Zatvori",
     "Daily" : "дневно",
     "Weekly" : "недељно",
+    "second" : "sekund",
     "Other" : "Ostali",
-    "Movie" : "Film",
-    "Mail" : "Pošta"
+    "Details" : "Detalji"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
