@@ -2,25 +2,9 @@
 
 declare(strict_types=1);
 
-/*
- * @copyright 2021 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @author 2021 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+/**
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Calendar\Listener;
@@ -53,6 +37,7 @@ class UserDeletedListener implements IEventListener {
 		$this->logger = $logger;
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		if (!($event instanceof UserDeletedEvent)) {
 			return;
@@ -61,6 +46,6 @@ class UserDeletedListener implements IEventListener {
 		$this->bookingService->deleteByUser($event->getUser());
 		$this->appointmentConfigService->deleteByUser($event->getUser());
 
-		$this->logger->info("Calendar appointments cleaned up for deleted user " . $event->getUser()->getUID());
+		$this->logger->info('Calendar appointments cleaned up for deleted user ' . $event->getUser()->getUID());
 	}
 }
